==================
django-authorities
==================

An application for managing your organization's authorities (departments, directorates etc)

Installation
============

Install it with ``pip install django-authorities``, or if you want to use the latest version on github, try ``pip install git+https://github.com/spapas/django-authorities``.

After it is installed, put ``authorities`` in your ``INSTALLED_APPS`` setting.  

Simple usage
============



v.0.1.1
-------

- Add template tags to get crud urls

v.0.1.0
-------

- Initial version
